@@ -1,6 +1,6 @@
 package swat;
 
-our $VERSION = '0.1.63';
+our $VERSION = '0.1.64';
 
 use base 'Exporter'; 
 
@@ -634,16 +634,22 @@ Swat variables define swat  basic configuration, like logging mode, prove runner
 
 =item *
 
-C<debug> - set to `1,2,3' if you want to see debug information in output, default value is `0'.
-Increasing debug value means more low level information appeared at console.
+C<skip_story> - skip story, default value is `0'. Set to `1' if you want skip store for some reasons.
 
 
+=back
 
-=item *
-
-C<debug_bytes> - number of bytes of http response  to be dumped out when debug is on. default value is `500'.
+For example:
 
+    # swat.ini
+    # assume that we set profile variable somewhere else
+    # 
+    
+    if test "${profile}" = 'production'; then
+        skip_story=1 # we don't want this one for production
+    fi
 
+=over
 
 =item *
 
@@ -657,6 +663,19 @@ C<prove_options> - prove options to be passed to prove runner,  default value is
 
 
 
+=item *
+
+C<debug> - set to `1,2,3' if you want to see debug information in output, default value is `0'.
+Increasing debug value means more low level information appeared at console.
+
+
+
+=item *
+
+C<debug_bytes> - number of bytes of http response  to be dumped out when debug is on. default value is `500'.
+
+
+
 =item *
 
 C<match_l> - in TAP output truncate matching strings to {match_l} bytes;  default value is `40'.
@@ -886,7 +905,7 @@ This is an example of setting server response inside swat hook:
     THIS IS FAKE RESPONSE
     HELLO WORLD
 
-Another interesting idea about setI<response feature is a >conditional_ http requests.
+Another interesting idea about set_response feature is a I<conditional> http requests.
 
 Let say we have `POST /login' request for user authentication, this is a simple swat story for it:
 
